function [ T ] = T_solver( u, rho, x0 )
% T_SOLVER  Calculates the temperature based on the updated states in the
%           storage tank and the vehicle tank.
%           The specific internal energy along with the density in the
%           tanks are known. 
%           fsolve is used to find what temperature corresponds to the two
%           known states.
%
% INPUTS
% u         Specific internal energy, [kJ/kg]
% rho       Density in tank, [kg/m3]
% x0        Initial guess of temperature. The temperature found in the
%           previous step is used.
%
% OUTPUTS
% T         New temperature in tank, [K]

%fsolve settings
options     = optimset('Display', 'off', 'TolX', 1e-4);

%Equation to be solved
F           = @(x)  u  - ...                                         
                    Props('U', 'T', x, 'D', rho, 'H2');

%Solver
T           = fsolve(F, x0, options);




end

