function [ Q , h_out ] = heatexchanger( mflow, T_in,  p_in, T_out)
% HEATEXCHANGER Calculates the heat exchanger duty from the steady-state 
%               energy balance:
%                                   Q = mflow*(h_in - h_out)
%               It is assumed that the pressure drop is zero across the 
%               heat exchanger, that is p_out = p_in.
%               The outlet temperature is predefined by the SAE TIR J2601.
%   
% INPUT
% mflow         Mass flow rate, [kg/s]
% T_in          Inlet temperature, [K]
% p_in          Inlet pressure, [MPa]
% T_out         Specified outlet temp., [K]
% 
% OUTPUT
% Q             Heat removed, [kW]
% h_out         Outlet enthalpy, [kJ/kg]

%Inlet conditions
h_in    = Props('H', 'P', p_in*1e3, 'T', T_in, 'H2');

%Outlet conditions
p_out   = p_in;               % No pressure drop
h_out   = Props('H', 'P', p_out*1e3, 'T', T_out, 'H2');

%Heat removed, [kW]
Q       = mflow*(h_in - h_out);

end