function [ mflow, T_out  ] = red_valve( p_in, T_in, rho_in, p_out, Cv )
% RED_VALVE     Calculates the expansion of the hydrogen gas through the
%               reduction valve. It is assumed that the expansion 
%               is adiabatic. That is; the flow is isenthalpic (dh = 0).
%               The massflow induced by the pressure difference and the
%               given valve coefficient (Cv) is also calculated.
%   
% INPUT
% p_in          Inlet pressure, [MPa]
% T_in          Inlet temperature, [K]
% rho_in        Inlet density, [kg/m3]
% p_out         Outlet pressure, [MPa]
% Cv            Valve coefficient
%
% OUTPUT
% mflow         Mass flow through valve, [kg/s]
% T_out         Outlet temperature, [K]

%Inlet conditions
h_in        = Props('H', 'P', p_in*1e3, 'T', T_in, 'H2');

%Outlet conditions
h_out       = h_in;
T_out       = Props('T', 'H', h_out, 'P', p_out*1e3, 'H2');

%Mass flow
mflow       = Cv*sqrt(((p_in - p_out)*1e6)/rho_in)*rho_in;


end

